@@ -5,7 +5,7 @@ use Module::Install::Base;
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.10';
+	$VERSION = '1.12';
 	@ISA     = qw{Module::Install::Base};
 }
 
@@ -160,20 +160,3 @@ under the same terms as Perl itself.
 See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 COPYRIGHT
-
-Copyright 2008 - 2014 Adam Kennedy.
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=cut
